%define debug_package %{nil}
%{!?python_sitelib: %define python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

Summary:	Python routines and frameworks helpful when developing analyses using the SiLK toolkit

Packager:	Lawrence R. Rogers (lrr@cert.org)

Vendor:		CERT Network Situational Awareness
Name:		netsa-python
Version:	1.4.3
Release:	1%{?dist}
URL:		http://tools.netsa.cert.org/netsa-python
License:	GPLv2
Group:		Applications/System

Source0:	%{name}-%{version}.tar.gz
%if 0%{?rhel} == 5 || 0%{?rhel} == 6
Patch0:         %{name}-%{version}_sphinx-build-fix.patch
Patch1:         %{name}-%{version}_build-manpages.patch
%endif
BuildRoot:	%{buildroot}
BuildRequires:	python 
%if 0%{?rhel} == 5 || 0%{?rhel} == 6
BuildRequires:  python-sphinx10
%else
BuildRequires:  python-sphinx >= 1.0
%endif

%description
The netsa-python library is a grab-bag of Python routines and frameworks
that the NetSA team at CERT has found helpful when developing analyses using the SiLK
toolkit. Of particular note are the netsa.script NetSA Scripting
Framework, which provides a standard framework for writing scripts that
process flow data, and the netsa.util.shell command line processing
system, which provides tools for managing extremely complicated
collections of shell processes that should fail or succeed together
(extremely useful when working with named pipes).

netsa-python is compatible with Python versions 2.4 and greater.

Here are the tools installed:

	netsa.script — The NetSA Scripting Framework
	netsa.sql — SQL Database Access
	netsa.util.shell — Robust Shell Pipelines

	Data Manipulation
		netsa.data.countries — Country and Region Codes
		netsa.data.format — Formatting Data for Output
		netsa.data.nice — “Nice” Numbers for Chart Bounds
		netsa.data.times — Time and Date Manipulation

	Miscellaneous Facilities
		netsa.files — File and Path Manipulation
		netsa.files.datefiles — Date-based filenames
		netsa.json — JSON Wrapper Module
		netsa.tools.service — Tools for building services
		netsa.util.clitest — Utility for testing CLI tools
		netsa.util.compat — Python version compatibility code

%prep
%setup

%build
%__python setup.py build

%install
%{__rm} -rf %{buildroot}
%{__python} setup.py install --root="%{buildroot}" --prefix="%{_prefix}"
%__install -d %{buildroot}/%{_bindir}

%clean
# %{__rm} -rf %{buildroot}

%files
%defattr(444, root, root, 0755)
%doc CHANGES GPL.txt LICENSE-OPENSOURCE.txt netsa-python-%{version}.pdf PKG-INFO 
%attr(0444, root, root)		%{python_sitelib}/netsa/VERSION
%attr(0444, root, root)		%{python_sitelib}/netsa/data/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/data/test/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/dist/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/dist/tools_web/layout.html
%attr(0444, root, root)		%{python_sitelib}/netsa/dist/tools_web/theme.conf
%attr(0444, root, root)		%{python_sitelib}/netsa/dist/tools_web/static/tools.css_t
%attr(0444, root, root)		%{python_sitelib}/netsa/files/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/files/test/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/json/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/json/simplejson/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/logging/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/script/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/sql/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/sql/test/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/tools/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/util/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/json/test/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/logging/test/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/_netsa_silk/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/_netsa_silk/test/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/script/golem/*.py*
%attr(0444, root, root)		%{python_sitelib}/netsa/util/test/*.py*
%attr(0444, root, root)		%{python_sitelib}/*.py*
%dir				%{python_sitelib}/netsa
%dir				%{python_sitelib}/netsa/data
%dir				%{python_sitelib}/netsa/data/test
%dir				%{python_sitelib}/netsa/dist
%dir				%{python_sitelib}/netsa/dist/tools_web
%dir				%{python_sitelib}/netsa/dist/tools_web/static
%dir				%{python_sitelib}/netsa/files
%dir				%{python_sitelib}/netsa/files/test
%dir				%{python_sitelib}/netsa/json
%dir				%{python_sitelib}/netsa/json/simplejson
%dir				%{python_sitelib}/netsa/logging
%dir				%{python_sitelib}/netsa/script
%dir				%{python_sitelib}/netsa/sql
%dir				%{python_sitelib}/netsa/sql/test
%dir				%{python_sitelib}/netsa/tools
%dir				%{python_sitelib}/netsa/util
%attr(444, root, root)		%{python_sitelib}/netsa_python*egg-info
%attr(444, root, root)		%{_datadir}/%{name}/sql/create-sa_meta-0.9.sql

%changelog
* Mon Feb 18 2013 Lawrence R. Rogers <lrr@cert.org> 1.4.3-1
* Release 1.4.3-1

	* Added server-side cursor support to netsa.sql's psycopg2 driver, so that results are streamed back instead of fetched all together.
	* Fixed an exception caused by using num_prefix on values <= 1e-21.
	* Remove netsa_silk support version SiLK versions older than SiLK 3.
	* Provide unnamed arguments to scripts via netsa.script.get_extra_args().
	* Better support for finding non-standard Sphinx installs.

* Fri Dec 7 2011 Lawrence R. Rogers <lrr@cert.org> 1.4.2-1
* Release 1.4.2-1

	* Fix problem where netsa.dist would not install manpages unless the
	  distribution also had install_data.

* Fri Nov 11 2011 Lawrence R. Rogers <lrr@cert.org> 1.4.1-1
* Release 1.4.1-1

	* Fail-on-use dummy IPv6Addr added to netsa_silk, so that the symbol
	  may still be imported even when IPv6 support is not provided.

	* Minor bug fixes to prevent setup.py from requiring sphinx, and to
	  improve documentation generation on projects with different needs.

* Mon Sep 30 2011 Lawrence R. Rogers <lrr@cert.org> 1.4-1
* Release 1.4-1
	* NOTE: Version 1.4 of NetSA Python is the last version that
	  will support Python 2.4.  Future major versions of NetSA Python
	  will require Python 2.6 or greater.

	* Added new netsa_silk module, which provides a bridge between
	  netsa-python and PySiLK.  When PySiLK is available, it uses PySiLK
	  to provide a fast C implementation of IP address and related
	  functionality.  When PySiLK is not available, a pure Python
	  implementation from netsa-python is used instead.

	* Added new netsa.script.golem script automation framework, for
	  building scripts to maintain large time-based data sets (among
	  other things.)

	* Added regex_help argument to netsa.script.add_text_param and
	  add_label_param, to support providing a more useful error message
	  when the regex doesn't match the input.

	* Added heapq.merge and os.path.relpath to netsa.util.compat.

	* Replaced all temporary file code with new functions in the
	  netsa.files module, to avoid duplication of effort.  Similar
	  functions in other locations have been deprecated and are now
	  implemented using this version.

	  Replaced PID locking code with new functions in the netsa.files
	  module, to avoid duplication of effort.

	* Improved netsa.data.nice's results, particularly for time ticks.

	* Added a large number of new tests to improve compatibility testing
	  for different versions of Python in the future.

	* Moved the netsa.script.get_temp_dir... functions into netsa.files,
	  with slight renaming.  The old functions are still available but
	  deprecated.

	* Deprecated netsa.files.DirLocker, netsa.files.LocalTmpDir, and
	  netsa.tools.service.  See the new functions
	  netsa.files.acquire_pidfile_lock, examine_pidfile_lock, and
	  release_pidfile_lock.

	* Deprecated netsa.files.datefiles.

	* Added documentation for the netsa.dist module, even though it is
	  primarily for internal use.

	* Fixed bug involving SIGPIPE handling in netsa.util.shell.

	* Fixed bug that prevented netsa.logging from importing correctly
	  under Python 2.7.

* Mon Mar 28 2011 Lawrence R. Rogers <lrr@cert.org> 1.3-1
* Release 1.3-1
	* Switched to new common installation mechanism (based on distutils)
	* Improved error handling in netsa.util.script
	* Added new function netsa.script.get_temp_dir_pipe_name()
	* Added timedelta support to netsa.data.times
	* Added new netsa.util.compat to activity “compatibility features”
